==> amanda_2.4.0.980319.orig.tar.gz: amanda-2.4.0.980319.orig/recover-src/amrecover.h <==
/*
 * Amanda, The Advanced Maryland Automatic Network Disk Archiver
 * Copyright (c) 1991, 1996 University of Maryland at College Park
 * All Rights Reserved.
 *
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the name of U.M. not be used in advertising or
 * publicity pertaining to distribution of the software without specific,
 * written prior permission.  U.M. makes no representations about the
 * suitability of this software for any purpose.  It is provided "as is"
 * without express or implied warranty.
 *
 * U.M. DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL U.M.
 * BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
 * OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * Author: James da Silva, Systems Design and Analysis Group
 *			   Computer Science Department
 *			   University of Maryland at College Park
 */
/*
 * $Id$
 *
 * data structures and declarations for amrecover
 */

#include "amanda.h"

typedef struct DIR_ITEM
{
    char date[11];
    int  level;
    char tape[256];
    char path[1024];

    struct DIR_ITEM *next;
}
DIR_ITEM;

extern char *server_name;
extern char *config;
extern char *dump_hostname;		/* which machine we are restoring */
extern char *disk_name;			/* disk we are restoring */
extern char *mount_point;		/* where disk was mounted */
extern char *disk_path;			/* path relative to mount point */
extern char dump_date[STR_SIZE];	/* date on which we are restoring */
extern int quit_prog;			/* set when time to exit parser */
extern char *tape_server_name;
extern char *tape_device_name;
extern pid_t extract_restore_child_pid;

extern int converse P((char *cmd));
extern int exchange P((char *cmd));
extern int server_happy P((void));
extern int send_command P((char *cmd));
extern int get_reply_line P((void));
extern char *reply_line P((void));

extern void quit P((void));

extern void help_list P((void));		/* list commands */

extern void set_disk P((char *dsk, char *mtpt));
extern void set_host P((char *host));
extern int set_date P((char *date));
extern void set_directory P((char *dir));
extern void show_directory P((void));

extern void list_disk_history P((void));
extern void list_directory P((void));
extern DIR_ITEM *get_dir_list P((void));
extern DIR_ITEM *get_next_dir_item P((DIR_ITEM *this));
extern void suck_dir_list_from_server P((void));
extern void clear_dir_list P((void));
extern void clean_pathname P((char *s));
extern void display_extract_list P((char *file));
extern void clear_extract_list P((void));
extern int is_extract_list_nonempty P((void));
extern void add_file P((char *path));
extern void delete_file P((char *path));

extern void extract_files P((void));

==> amanda_2.4.1p1.orig.tar.gz: amanda-2.4.1p1/recover-src/amrecover.h <==
/*
 * Amanda, The Advanced Maryland Automatic Network Disk Archiver
 * Copyright (c) 1991-1998 University of Maryland at College Park
 * All Rights Reserved.
 *
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the name of U.M. not be used in advertising or
 * publicity pertaining to distribution of the software without specific,
 * written prior permission.  U.M. makes no representations about the
 * suitability of this software for any purpose.  It is provided "as is"
 * without express or implied warranty.
 *
 * U.M. DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL U.M.
 * BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
 * OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * Authors: the Amanda Development Team.  Its members are listed in a
 * file named AUTHORS, in the root directory of this distribution.
 */
/*
 * $Id$
 *
 * data structures and declarations for amrecover
 */

#include "amanda.h"

typedef struct DIR_ITEM
{
    char date[11];
    int  level;
    char tape[256];
    char path[1024];

    struct DIR_ITEM *next;
}
DIR_ITEM;

extern char *server_name;
extern char *config;
extern char *dump_datestamp;		/* date we are restoring */
extern char *dump_hostname;		/* which machine we are restoring */
extern char *disk_name;			/* disk we are restoring */
extern char *mount_point;		/* where disk was mounted */
extern char *disk_path;			/* path relative to mount point */
extern char dump_date[STR_SIZE];	/* date on which we are restoring */
extern int quit_prog;			/* set when time to exit parser */
extern char *tape_server_name;
extern char *tape_device_name;
extern pid_t extract_restore_child_pid;

extern int converse P((char *cmd));
extern int exchange P((char *cmd));
extern int server_happy P((void));
extern int send_command P((char *cmd));
extern int get_reply_line P((void));
extern char *reply_line P((void));

extern void quit P((void));

extern void help_list P((void));		/* list commands */

extern void set_disk P((char *dsk, char *mtpt));
extern void set_host P((char *host));
extern int set_date P((char *date));
extern void set_directory P((char *dir));
extern void show_directory P((void));

extern void list_disk_history P((void));
extern void list_directory P((void));
extern DIR_ITEM *get_dir_list P((void));
extern DIR_ITEM *get_next_dir_item P((DIR_ITEM *this));
extern void suck_dir_list_from_server P((void));
extern void clear_dir_list P((void));
extern void clean_pathname P((char *s));
extern void display_extract_list P((char *file));
extern void clear_extract_list P((void));
extern int is_extract_list_nonempty P((void));
extern void add_glob P((char *glob));
extern void add_regex P((char *regex));
extern void add_file P((char *path, char *regex));
extern void delete_glob P((char *glob));
extern void delete_regex P((char *regex));
extern void delete_file P((char *path, char *regex));

extern void extract_files P((void));
